File indexing completed on 2026-08-27 08:33:40
0001
0002
0003
0004
0005
0006
0007
0008
0009 #include <cstdint>
0010
0011 #include "CudaUnavailable.hpp"
0012 #include "DeviceOps.hpp"
0013
0014 namespace ActsPlugins::detail {
0015
0016 TensorPtr cudaCreateTensorMemory(std::size_t ,
0017 const ExecutionContext & ) {
0018 throwNoCudaSupport("create CUDA tensor");
0019 }
0020
0021 void cudaCopyTensorMemory(void * , const void * ,
0022 std::size_t , Device ,
0023 const ExecutionContext & ) {
0024 throwNoCudaSupport("copy CUDA tensor memory");
0025 }
0026
0027 void cudaSigmoid(Tensor<float> & , cudaStream_t ) {
0028 throwNoCudaSupport("apply sigmoid to CUDA tensor");
0029 }
0030
0031 Tensor<bool> cudaScoreMask(const Tensor<float> & , float ,
0032 cudaStream_t ) {
0033 throwNoCudaSupport("compute score mask on CUDA tensor");
0034 }
0035
0036 template <typename T>
0037 Tensor<T> cudaSelectRows(const Tensor<T> & ,
0038 const Tensor<bool> & ,
0039 const ExecutionContext & ) {
0040 throwNoCudaSupport("selectRows on CUDA tensor");
0041 }
0042
0043 template <typename T>
0044 Tensor<T> cudaSelectCols(const Tensor<T> & ,
0045 const Tensor<bool> & ,
0046 const ExecutionContext & ) {
0047 throwNoCudaSupport("selectCols on CUDA tensor");
0048 }
0049
0050 template <typename T>
0051 Tensor<T> cudaMulPerColumn(const Tensor<T> & ,
0052 const Tensor<T> & ,
0053 const ExecutionContext & ) {
0054 throwNoCudaSupport("apply feature scales on CUDA tensor");
0055 }
0056
0057 PipelineTensors cudaRemoveUnusedNodes(PipelineTensors && ,
0058 std::vector<int> & ,
0059 const ExecutionContext & ) {
0060 throwNoCudaSupport("removeUnusedNodes on CUDA tensor");
0061 }
0062
0063
0064
0065 template Tensor<float> cudaSelectRows(const Tensor<float> &,
0066 const Tensor<bool> &,
0067 const ExecutionContext &);
0068 template Tensor<std::int64_t> cudaSelectRows(const Tensor<std::int64_t> &,
0069 const Tensor<bool> &,
0070 const ExecutionContext &);
0071 template Tensor<float> cudaSelectCols(const Tensor<float> &,
0072 const Tensor<bool> &,
0073 const ExecutionContext &);
0074 template Tensor<std::int64_t> cudaSelectCols(const Tensor<std::int64_t> &,
0075 const Tensor<bool> &,
0076 const ExecutionContext &);
0077 template Tensor<float> cudaMulPerColumn(const Tensor<float> &,
0078 const Tensor<float> &,
0079 const ExecutionContext &);
0080 template Tensor<std::int64_t> cudaMulPerColumn(const Tensor<std::int64_t> &,
0081 const Tensor<std::int64_t> &,
0082 const ExecutionContext &);
0083
0084 }